@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -111,7 +107,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
                "",
             };
         final String[] Gulf = new String[] {
-               "Hora del Golf",
+               "Hora est\u00e0ndard del Golf",
                "",
                "",
                "",
@@ -127,11 +123,11 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
                "",
             };
         final String[] Iran = new String[] {
-               "Hora est\u00e0ndard d\u2019Iran",
+               "Hora est\u00e0ndard de l\u2019Iran",
                "",
-               "Hora d\u2019estiu d\u2019Iran",
+               "Hora d\u2019estiu de l\u2019Iran",
                "",
-               "Hora d\u2019Iran",
+               "Hora de l\u2019Iran",
                "",
             };
         final String[] Niue = new String[] {
@@ -167,7 +163,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
                "",
             };
         final String[] Wake = new String[] {
-               "Hora de Wake",
+               "Hora de les illes Wake",
                "",
                "",
                "",
@@ -551,7 +547,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
                "",
             };
         final String[] Solomon = new String[] {
-               "Hora de Salom\u00f3",
+               "Hora de les illes Salom\u00f3",
                "",
                "",
                "",
@@ -607,7 +603,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
                "",
             };
         final String[] Chamorro = new String[] {
-               "Hora de Chamorro",
+               "Hora est\u00e0ndard de Chamorro",
                "",
                "",
                "",
@@ -727,7 +723,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
                "",
             };
         final String[] Indochina = new String[] {
-               "Hora d\u2019Indoxina",
+               "Hora de l\u2019Indoxina",
                "",
                "",
                "",
@@ -758,14 +754,6 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
                "Hora de Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Hora de Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Hora de les Marqueses",
                "",
@@ -807,19 +795,19 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
                "",
             };
         final String[] Azerbaijan = new String[] {
-               "Hora est\u00e0ndard d\u2019Azerbaidjan",
+               "Hora est\u00e0ndard de l\u2019Azerbaidjan",
                "",
-               "Hora d\u2019estiu d\u2019Azerbaidjan",
+               "Hora d\u2019estiu de l\u2019Azerbaidjan",
                "",
-               "Hora d\u2019Azerbaidjan",
+               "Hora de l\u2019Azerbaidjan",
                "",
             };
         final String[] Bangladesh = new String[] {
-               "Hora est\u00e0ndard de Bangla Desh",
+               "Hora est\u00e0ndard de Bangladesh",
                "",
-               "Hora d\u2019estiu de Bangla Desh",
+               "Hora d\u2019estiu de Bangladesh",
                "",
-               "Hora de Bangla Desh",
+               "Hora de Bangladesh",
                "",
             };
         final String[] Cape_Verde = new String[] {
@@ -895,11 +883,11 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
                "",
             };
         final String[] Philippines = new String[] {
-               "Hora est\u00e0ndard de Filipines",
+               "Hora est\u00e0ndard de les Filipines",
                "",
-               "Hora d\u2019estiu de Filipines",
+               "Hora d\u2019estiu de les Filipines",
                "",
-               "Hora de Filipines",
+               "Hora de les Filipines",
                "",
             };
         final String[] Vladivostok = new String[] {
@@ -1292,7 +1280,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1442,7 +1430,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1567,7 +1555,6 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1647,7 +1634,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1687,7 +1674,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1750,7 +1737,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Riyadh", "Al-Riy\u0101d" },
             { "timezone.excity.Asia/Taipei", "Taipei" },
             { "timezone.excity.Asia/Tehran", "Teheran" },
-            { "timezone.excity.Asia/Urumqi", "Urumchi" },
+            { "timezone.excity.Asia/Urumqi", "\u00dcr\u00fcmchi" },
             { "timezone.excity.Etc/Unknown", "Ciutat desconeguda" },
             { "timezone.excity.Europe/Kiev", "K\u00edev" },
             { "timezone.excity.Europe/Oslo", "Oslo" },
@@ -1999,7 +1986,6 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Bucharest", "Bucarest" },
             { "timezone.excity.Europe/Gibraltar", "Gibraltar" },
             { "timezone.excity.Europe/Ljubljana", "Ljubljana" },
-            { "timezone.excity.Europe/Mariehamn", "Maarianhamina" },
             { "timezone.excity.Europe/Podgorica", "Podgorica" },
             { "timezone.excity.Europe/Stockholm", "Estocolm" },
             { "timezone.excity.Europe/Ulyanovsk", "Uli\u00e0novsk" },
@@ -2042,7 +2028,7 @@ public class TimeZoneNames_ca extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Copenhagen", "Copenhagen" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
             { "timezone.excity.Europe/San_Marino", "San Marino" },
-            { "timezone.excity.Europe/Simferopol", "Simferopol" },
+            { "timezone.excity.Europe/Simferopol", "Simfer\u00f2pol" },
             { "timezone.excity.Europe/Zaporozhye", "Zapor\u00edjia" },
             { "timezone.excity.Pacific/Enderbury", "Enderbury" },
             { "timezone.excity.Pacific/Galapagos", "Gal\u00e1pagos" },
