@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -95,11 +91,11 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
                "",
             };
         final String[] Cuba = new String[] {
-               "Amser Safonol Cuba",
+               "Amser Safonol Ciwba",
                "",
-               "Amser Haf Cuba",
+               "Amser Haf Ciwa",
                "",
-               "Amser Cuba",
+               "Amser Ciwba",
                "",
             };
         final String[] Fiji = new String[] {
@@ -215,11 +211,11 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
                "",
             };
         final String[] Japan = new String[] {
-               "Amser Safonol Siapan",
+               "Amser Safonol Japan",
                "",
-               "Amser Haf Siapan",
+               "Amser Haf Japan",
                "",
-               "Amser Siapan",
+               "Amser Japan",
                "",
             };
         final String[] Korea = new String[] {
@@ -439,7 +435,7 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
                "",
             };
         final String[] Bolivia = new String[] {
-               "Amser Bolivia",
+               "Amser Bolifia",
                "",
                "",
                "",
@@ -742,14 +738,6 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
                "Amser yr Arglwydd Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Amser Ynys Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Amser Marquises",
                "",
@@ -1276,7 +1264,7 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Aqtobe", Kazakhstan_Western },
@@ -1425,7 +1413,7 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1549,7 +1537,6 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1629,7 +1616,7 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1669,7 +1656,7 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1816,7 +1803,6 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/London", "Llundain" },
             { "timezone.excity.Europe/Madrid", "Madrid" },
             { "timezone.excity.Europe/Monaco", "Monaco" },
-            { "timezone.excity.Europe/Moscow", "Moscfa" },
             { "timezone.excity.Europe/Prague", "Prag" },
             { "timezone.excity.Europe/Samara", "Samara" },
             { "timezone.excity.Europe/Skopje", "Skopje" },
@@ -2086,6 +2072,7 @@ public class TimeZoneNames_cy extends TimeZoneNamesBundle {
             { "timezone.excity.America/Cambridge_Bay", "Bae Cambridge" },
             { "timezone.excity.America/Port_of_Spain", "Port of Spain" },
             { "timezone.excity.America/Santo_Domingo", "Santo Domingo" },
+            { "timezone.excity.America/St_Barthelemy", "St. Barth\u00e9lemy" },
             { "timezone.excity.America/Swift_Current", "Swift Current" },
             { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
             { "timezone.excity.America/Bahia_Banderas", "Bae Banderas" },
