@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -118,22 +114,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "hora de la isla de Pascua",
                "",
             };
-        final String[] ETC_UTC = new String[] {
-               "hora universal coordinada",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Irkutsk = new String[] {
-               "hora est\u00e1ndar de Irkutsh",
-               "",
-               "hora de verano de Irkutsh",
-               "",
-               "hora de Irkutsk",
-               "",
-            };
         final String[] Norfolk = new String[] {
                "hora est\u00e1ndar de la isla Norfolk",
                "",
@@ -174,22 +154,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "hora de las islas Malvinas",
                "",
             };
-        final String[] Christmas = new String[] {
-               "hora de la isla de Navidad",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Macquarie = new String[] {
-               "hora de la isla Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "hora de las islas Marquesas",
                "",
@@ -198,6 +162,14 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] EMPTY_ZONE = new String[] {
+               "",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Indian_Ocean = new String[] {
                "hora del Oc\u00e9ano \u00cdndico",
                "",
@@ -307,7 +279,7 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
             { "Europe/Bucharest", Europe_Eastern },
-            { "UTC", ETC_UTC },
+            { "UTC", EMPTY_ZONE },
             { "ART", Europe_Eastern },
             { "AST", Alaska },
             { "CST", America_Central },
@@ -318,7 +290,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "SST", Solomon },
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
-            { "Etc/UTC", ETC_UTC },
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Gaza", Europe_Eastern },
@@ -330,7 +301,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "Africa/Cairo", Europe_Eastern },
             { "America/Adak", Hawaii_Aleutian },
             { "America/Nome", Alaska },
-            { "Asia/Irkutsk", Irkutsk },
             { "Asia/Nicosia", Europe_Eastern },
             { "Europe/Sofia", Europe_Eastern },
             { "Indian/Cocos", Cocos },
@@ -362,7 +332,7 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
             { "America/Merida", America_Central },
@@ -417,7 +387,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "Atlantic/Madeira", Europe_Western },
             { "Atlantic/Stanley", Falkland },
             { "Europe/Mariehamn", Europe_Eastern },
-            { "Indian/Christmas", Christmas },
             { "Pacific/Johnston", Hawaii_Aleutian },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -441,7 +410,7 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Europe/Kaliningrad", Europe_Eastern },
             { "America/El_Salvador", America_Central },
             { "America/Fort_Nelson", America_Mountain },
@@ -457,7 +426,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
-            { "Antarctica/Macquarie", Macquarie },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
@@ -476,8 +444,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
-            { "timezone.excity.Asia/Almaty", "Almat\u00fd" },
-            { "timezone.excity.Asia/Barnaul", "Barnaul" },
             { "timezone.excity.Europe/Kirov", "Kirov" },
             { "timezone.excity.Pacific/Wake", "Wake" },
             { "America/North_Dakota/New_Salem", America_Central },
@@ -487,7 +453,6 @@ public class TimeZoneNames_es_US extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Ulyanovsk", "Ulyanovsk" },
             { "timezone.excity.Pacific/Honolulu", "Honolulu" },
             { "timezone.excity.America/St_Thomas", "St. Thomas" },
-            { "timezone.excity.America/Rio_Branco", "Rio Branco" },
             { "timezone.excity.America/Fort_Nelson", "Fort Nelson" },
         };
         return data;
