@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -270,14 +266,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure de l\u2019Arm\u00e9nie",
                "",
             };
-        final String[] Chatham = new String[] {
-               "heure normale des \u00celes Chatham",
-               "",
-               "heure avanc\u00e9e des \u00celes Chatham",
-               "",
-               "heure des \u00eeles Chatham",
-               "",
-            };
         final String[] ETC_UTC = new String[] {
                "temps universel coordonn\u00e9",
                "",
@@ -607,27 +595,27 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "",
             };
         final String[] Europe_Central = new String[] {
-               "heure normale d\u2019Europe centrale",
+               "heure normale de l\u2019Europe centrale",
                "",
-               "heure avanc\u00e9e d\u2019Europe centrale",
+               "heure avanc\u00e9e de l\u2019Europe centrale",
                "",
-               "heure d\u2019Europe centrale",
+               "heure de l\u2019Europe centrale",
                "",
             };
         final String[] Europe_Eastern = new String[] {
-               "heure normale d\u2019Europe de l\u2019Est",
+               "heure normale de l\u2019Europe de l\u2019Est",
                "",
-               "heure avanc\u00e9e d\u2019Europe de l\u2019Est",
+               "heure avanc\u00e9e de l\u2019Europe de l\u2019Est",
                "",
-               "heure d\u2019Europe de l\u2019Est",
+               "heure de l\u2019Europe de l\u2019Est",
                "",
             };
         final String[] Europe_Western = new String[] {
-               "heure normale d\u2019Europe de l\u2019Ouest",
+               "heure normale de l\u2019Europe de l\u2019Ouest",
                "",
-               "heure avanc\u00e9e d\u2019Europe de l\u2019Ouest",
+               "heure avanc\u00e9e de l\u2019Europe de l\u2019Ouest",
                "",
-               "heure d\u2019Europe de l\u2019Ouest",
+               "heure de l\u2019Europe de l\u2019Ouest",
                "",
             };
         final String[] Mexico_Pacific = new String[] {
@@ -804,7 +792,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Asia/Anadyr", Anadyr },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Harbin", China },
@@ -913,7 +901,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
@@ -990,7 +978,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Europe/Helsinki", Europe_Eastern },
             { "Europe/Sarajevo", Europe_Central },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "Pacific/Chatham", Chatham },
             { "Pacific/Norfolk", Norfolk },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
@@ -1016,7 +1003,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
             { "Asia/Ulaanbaatar", Mongolia },
@@ -1079,7 +1065,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
@@ -1112,6 +1098,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
