@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -182,6 +178,14 @@ public class TimeZoneNames_nl extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "Casey tijd",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Chileense standaardtijd",
                "",
@@ -471,7 +475,7 @@ public class TimeZoneNames_nl extends TimeZoneNamesBundle {
                "",
             };
         final String[] ETC_UTC = new String[] {
-               "Geco\u00f6rdineerde wereldtijd",
+               "geco\u00f6rdineerde wereldtijd",
                "UTC",
                "",
                "",
@@ -766,14 +770,6 @@ public class TimeZoneNames_nl extends TimeZoneNamesBundle {
                "Lord Howe-eilandse tijd",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Macquarie-eilandse tijd",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Marquesaseilandse tijd",
                "",
@@ -1309,7 +1305,7 @@ public class TimeZoneNames_nl extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1468,7 +1464,7 @@ public class TimeZoneNames_nl extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1594,7 +1590,7 @@ public class TimeZoneNames_nl extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1675,7 +1671,7 @@ public class TimeZoneNames_nl extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1715,7 +1711,7 @@ public class TimeZoneNames_nl extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1968,7 +1964,7 @@ public class TimeZoneNames_nl extends TimeZoneNamesBundle {
             { "timezone.excity.America/Tortola", "Tortola" },
             { "timezone.excity.America/Yakutat", "Yakutat" },
             { "timezone.excity.Asia/Choibalsan", "Tsjojbalsan" },
-            { "timezone.excity.Asia/Phnom_Penh", "Phnom-Penh" },
+            { "timezone.excity.Asia/Phnom_Penh", "Phnom Penh" },
             { "timezone.excity.Atlantic/Azores", "Azoren" },
             { "timezone.excity.Atlantic/Canary", "Canarische Eilanden" },
             { "timezone.excity.Atlantic/Faeroe", "Faer\u00f6er" },
