@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -134,6 +130,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Iran",
                "",
             };
+        final String[] Niue = new String[] {
+               "czas Niue",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Omsk = new String[] {
                "Omsk (czas standardowy)",
                "",
@@ -158,6 +162,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Wake = new String[] {
+               "czas Wake",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Chile (czas standardowy)",
                "",
@@ -182,6 +194,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Davis = new String[] {
+               "czas Davis",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] India = new String[] {
                "czas indyjski standardowy",
                "",
@@ -206,6 +226,30 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Korea",
                "",
             };
+        final String[] Nauru = new String[] {
+               "czas Nauru",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Nepal = new String[] {
+               "czas Nepal",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Palau = new String[] {
+               "czas Palau",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Samoa = new String[] {
                "Samoa (czas standardowy)",
                "",
@@ -214,6 +258,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Samoa",
                "",
             };
+        final String[] Syowa = new String[] {
+               "czas Syowa",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Tonga = new String[] {
                "Tonga (czas standardowy)",
                "",
@@ -254,6 +306,22 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Azory",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "czas Bhutan",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Brunei = new String[] {
+               "czas Brunei",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Easter = new String[] {
                "Wyspa Wielkanocna (czas standardowy)",
                "",
@@ -278,6 +346,22 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Izrael",
                "",
             };
+        final String[] Kosrae = new String[] {
+               "czas Kosrae",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Mawson = new String[] {
+               "czas Mawson",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Moscow = new String[] {
                "Moskwa (czas standardowy)",
                "",
@@ -302,6 +386,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Samara",
                "",
             };
+        final String[] Tahiti = new String[] {
+               "czas Tahiti",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Taipei = new String[] {
                "Tajpej (czas standardowy)",
                "",
@@ -310,6 +402,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Tajpej",
                "",
             };
+        final String[] Tuvalu = new String[] {
+               "czas Tuvalu",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Vostok = new String[] {
                "czas Wostok",
                "",
@@ -414,6 +514,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Norfolk = new String[] {
+               "Norfolk (czas standardowy)",
+               "",
+               "Norfolk (czas letni)",
+               "",
+               "czas Norfolk",
+               "",
+            };
         final String[] Noronha = new String[] {
                "Fernando de Noronha (czas standardowy)",
                "",
@@ -422,6 +530,22 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Fernando de Noronha",
                "",
             };
+        final String[] Reunion = new String[] {
+               "czas Reunion",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
+        final String[] Rothera = new String[] {
+               "czas Rothera",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Solomon = new String[] {
                "czas Wyspy Salomona",
                "",
@@ -430,6 +554,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Tokelau = new String[] {
+               "czas Tokelau",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Uruguay = new String[] {
                "Urugwaj (czas standardowy)",
                "",
@@ -534,6 +666,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "czas Paragwaj",
                "",
             };
+        final String[] Pitcairn = new String[] {
+               "czas Pitcairn",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Sakhalin = new String[] {
                "Sachalin (czas standardowy)",
                "",
@@ -566,6 +706,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Galapagos = new String[] {
+               "czas Galapagos",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Hong_Kong = new String[] {
                "Hongkong (czas standardowy)",
                "",
@@ -1132,13 +1280,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
             { "Asia/Aqtobe", Kazakhstan_Western },
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Asia/Beirut", Europe_Eastern },
+            { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
             { "Asia/Hebron", Europe_Eastern },
             { "Asia/Kuwait", Arabian },
@@ -1176,6 +1325,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Asia/Nicosia", Europe_Eastern },
             { "Asia/Rangoon", Myanmar },
             { "Asia/Tbilisi", Georgia },
+            { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
             { "Europe/Malta", Europe_Central },
@@ -1186,11 +1336,14 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Pacific/Apia", Apia },
             { "Pacific/Fiji", Fiji },
             { "Pacific/Guam", Chamorro },
+            { "Pacific/Niue", Niue },
             { "Pacific/Truk", Truk },
+            { "Pacific/Wake", Wake },
             { "SystemV/AST4", Atlantic },
             { "SystemV/CST6", America_Central },
             { "SystemV/EST5", America_Eastern },
             { "SystemV/MST7", America_Mountain },
+            { "SystemV/PST8", Pitcairn },
             { "SystemV/YST9", Gambier },
             { "Africa/Asmera", Africa_Eastern },
             { "Africa/Bamako", GMT },
@@ -1217,6 +1370,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
+            { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
             { "Asia/Qostanay", Kazakhstan_Eastern },
@@ -1261,6 +1415,8 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Indian/Chagos", Indian_Ocean },
             { "Indian/Comoro", Africa_Eastern },
             { "Pacific/Efate", Vanuatu },
+            { "Pacific/Nauru", Nauru },
+            { "Pacific/Palau", Palau },
             { "SystemV/HST10", Hawaii_Aleutian },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
@@ -1274,7 +1430,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1311,12 +1467,15 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Europe/Vatican", Europe_Central },
             { "Europe/Vilnius", Europe_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
+            { "Indian/Reunion", Reunion },
             { "Pacific/Easter", Easter },
+            { "Pacific/Kosrae", Kosrae },
             { "Pacific/Majuro", Marshall_Islands },
             { "Pacific/Midway", Samoa },
             { "Pacific/Noumea", New_Caledonia },
             { "Pacific/Ponape", Ponape },
             { "Pacific/Saipan", Chamorro },
+            { "Pacific/Tahiti", Tahiti },
             { "Pacific/Tarawa", Gilbert_Islands },
             { "Pacific/Wallis", Wallis },
             { "Africa/Blantyre", Africa_Central },
@@ -1370,7 +1529,9 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Europe/Uzhgorod", Europe_Eastern },
             { "Indian/Maldives", Maldives },
             { "Pacific/Chatham", Chatham },
+            { "Pacific/Fakaofo", Tokelau },
             { "Pacific/Gambier", Gambier },
+            { "Pacific/Norfolk", Norfolk },
             { "SystemV/AST4ADT", Atlantic },
             { "SystemV/CST6CDT", America_Central },
             { "SystemV/EST5EDT", America_Eastern },
@@ -1394,7 +1555,8 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Davis", Davis },
+            { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "Asia/Novosibirsk", Novosibirsk },
@@ -1418,7 +1580,9 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
             { "Pacific/Auckland", New_Zealand },
+            { "Pacific/Funafuti", Tuvalu },
             { "Pacific/Johnston", Hawaii_Aleutian },
+            { "Pacific/Pitcairn", Pitcairn },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
             { "Africa/Nouakchott", GMT },
@@ -1438,6 +1602,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "America/Sao_Paulo", Brasilia },
             { "America/St_Thomas", Atlantic },
             { "America/Vancouver", America_Pacific },
+            { "Antarctica/Mawson", Mawson },
             { "Antarctica/Vostok", Vostok },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Asia/Novokuznetsk", Krasnoyarsk },
@@ -1448,6 +1613,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "Europe/Simferopol", Moscow },
             { "Europe/Zaporozhye", Europe_Eastern },
             { "Pacific/Enderbury", Phoenix_Islands },
+            { "Pacific/Galapagos", Galapagos },
             { "Pacific/Kwajalein", Marshall_Islands },
             { "Pacific/Marquesas", Marquesas },
             { "Pacific/Pago_Pago", Samoa },
@@ -1468,8 +1634,9 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
+            { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
@@ -1507,6 +1674,7 @@ public class TimeZoneNames_pl extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
