@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -527,12 +523,12 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                "",
             };
         final String[] Norfolk = new String[] {
+               "Hora padr\u00e3o da Ilha Norfolk",
+               "",
+               "Hora de ver\u00e3o da Ilha Norfolk",
+               "",
                "Hora da Ilha Norfolk",
                "",
-               "Hor\u00e1rio de Ver\u00e3o da Ilha Norfolk",
-               "",
-               "Hor\u00e1rio da Ilha Norfolk",
-               "",
             };
         final String[] Noronha = new String[] {
                "Hora padr\u00e3o de Fernando de Noronha",
@@ -766,14 +762,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                "Hora de Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Hora da Ilha Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Hora das Ilhas Marquesas",
                "",
@@ -1300,7 +1288,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1450,7 +1438,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1576,7 +1564,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1657,7 +1644,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1684,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1732,7 +1719,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Asia/Aqtobe", "Aqtobe" },
             { "timezone.excity.Asia/Kuwait", "Koweit" },
-            { "timezone.excity.Asia/Saigon", "Cidade de Ho Chi Minh" },
             { "timezone.excity.Asia/Taipei", "Taip\u00e9" },
             { "timezone.excity.Asia/Tehran", "Teer\u00e3o" },
             { "timezone.excity.Indian/Mahe", "Mahe" },
@@ -1764,6 +1750,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Tripoli", "Tripoli" },
             { "timezone.excity.America/Cancun", "Cancun" },
             { "timezone.excity.America/Cayman", "Caim\u00e3o" },
+            { "timezone.excity.Europe/Tallinn", "Talim" },
             { "timezone.excity.Pacific/Easter", "Ilha da P\u00e1scoa" },
             { "timezone.excity.Pacific/Tarawa", "Tarawa" },
             { "timezone.excity.Africa/Djibouti", "Jibuti" },
