@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -519,11 +515,11 @@ public class TimeZoneNames_sl extends TimeZoneNamesBundle {
                "",
             };
         final String[] Norfolk = new String[] {
-               "Norfol\u0161ki otoki standardni \u010das",
+               "Standardni \u010das: Norfol\u0161ki otoki",
                "",
-               "Norfol\u0161ki otoki poletni \u010das",
+               "Poletni \u010das: Norfol\u0161ki otoki",
                "",
-               "Norfol\u0161ki otoki \u010das",
+               "\u010cas: Norfol\u0161ki otoki",
                "",
             };
         final String[] Noronha = new String[] {
@@ -758,14 +754,6 @@ public class TimeZoneNames_sl extends TimeZoneNamesBundle {
                "\u010cas otoka Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Macquarieski \u010das",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "\u010cas: Markizni otoki",
                "",
@@ -1292,7 +1280,7 @@ public class TimeZoneNames_sl extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1442,7 +1430,7 @@ public class TimeZoneNames_sl extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1567,7 +1555,6 @@ public class TimeZoneNames_sl extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1647,7 +1634,7 @@ public class TimeZoneNames_sl extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1687,7 +1674,7 @@ public class TimeZoneNames_sl extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1943,6 +1930,7 @@ public class TimeZoneNames_sl extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Phnom_Penh", "Phnom Penh" },
             { "timezone.excity.Atlantic/Azores", "Azori" },
             { "timezone.excity.Atlantic/Canary", "Kanarski otoki" },
+            { "timezone.excity.Atlantic/Faeroe", "Ferski otoki" },
             { "timezone.excity.Australia/Eucla", "Eucla" },
             { "timezone.excity.Australia/Perth", "Perth" },
             { "timezone.excity.Europe/Belgrade", "Beograd" },
