@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,7 +67,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
-               "Waqtiga Celceliska Giriinwij",
+               "Wakhtiga Giriinwij",
                "",
                "",
                "",
@@ -766,14 +762,6 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
                "Waqtiga Lod How",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Waqtiga Makquwariy Aylaan",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Waqtiga Marquwesas",
                "",
@@ -1300,7 +1288,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1401,7 +1389,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
                 new String[] {
-                    "Waqtiga Celceliska Giriinwij",
+                    "Wakhtiga Giriinwij",
                     "",
                     "Waqtiga Caadiga Ah ee Ayrishka",
                     "",
@@ -1413,7 +1401,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
-                    "Waqtiga Celceliska Giriinwij",
+                    "Wakhtiga Giriinwij",
                     "",
                     "Waqtiga Xagaaga ee Biritishka",
                     "",
@@ -1450,7 +1438,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1475,7 +1463,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
-                    "Waqtiga Celceliska Giriinwij",
+                    "Wakhtiga Giriinwij",
                     "",
                     "Waqtiga Xagaaga ee Biritishka",
                     "",
@@ -1576,7 +1564,6 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1657,7 +1644,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1697,7 +1684,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1753,7 +1740,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Taipei", "Teybey" },
             { "timezone.excity.Asia/Tehran", "Tehraan" },
             { "timezone.excity.Etc/Unknown", "Magaalo Aan La Garanayn" },
-            { "timezone.excity.Europe/Kiev", "Kiyf" },
+            { "timezone.excity.Europe/Kiev", "Kiyeef" },
             { "timezone.excity.Europe/Riga", "Riija" },
             { "timezone.excity.Europe/Rome", "Rooma" },
             { "timezone.excity.Africa/Accra", "Akra" },
@@ -1816,15 +1803,15 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Dublin", "Dhaablin" },
             { "timezone.excity.Europe/Jersey", "Jaarsey" },
             { "timezone.excity.Europe/London", "Landan" },
-            { "timezone.excity.Europe/Madrid", "Maadriid" },
+            { "timezone.excity.Europe/Madrid", "Madriid" },
             { "timezone.excity.Europe/Monaco", "Monako" },
             { "timezone.excity.Europe/Moscow", "Moskow" },
             { "timezone.excity.Europe/Prague", "Baraag" },
             { "timezone.excity.Europe/Skopje", "Iskoobje" },
             { "timezone.excity.Europe/Tirane", "Tiraane" },
-            { "timezone.excity.Europe/Vienna", "Fiyaana" },
-            { "timezone.excity.Europe/Zagreb", "Sagreb" },
-            { "timezone.excity.Europe/Zurich", "Surij" },
+            { "timezone.excity.Europe/Vienna", "Fiyeena" },
+            { "timezone.excity.Europe/Zagreb", "Saqrib" },
+            { "timezone.excity.Europe/Zurich", "Suurikh" },
             { "timezone.excity.Indian/Chagos", "Jagos" },
             { "timezone.excity.Indian/Comoro", "Komoro" },
             { "timezone.excity.Pacific/Nauru", "Nawroo" },
@@ -1919,7 +1906,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Atlantic/Faeroe", "Farow" },
             { "timezone.excity.Australia/Eucla", "Yukla" },
             { "timezone.excity.Australia/Perth", "Bert" },
-            { "timezone.excity.Europe/Belgrade", "Bilgaraydh" },
+            { "timezone.excity.Europe/Belgrade", "Belgaraydh" },
             { "timezone.excity.Europe/Brussels", "Barasalis" },
             { "timezone.excity.Europe/Budapest", "Budabest" },
             { "timezone.excity.Europe/Busingen", "Busingeen" },
@@ -1957,7 +1944,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Novosibirsk", "Nofosibirsik" },
             { "timezone.excity.Asia/Vladivostok", "Faladifostok" },
             { "timezone.excity.Atlantic/Bermuda", "Barmuuda" },
-            { "timezone.excity.Atlantic/Madeira", "Madeera" },
+            { "timezone.excity.Atlantic/Madeira", "Madira" },
             { "timezone.excity.Atlantic/Stanley", "Istaanley" },
             { "timezone.excity.Australia/Currie", "Kuriy" },
             { "timezone.excity.Australia/Hobart", "Hubaart" },
@@ -2003,7 +1990,7 @@ public class TimeZoneNames_so extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Novokuznetsk", "Nofokusnetsik" },
             { "timezone.excity.Europe/Bratislava", "Baratislafa" },
             { "timezone.excity.Europe/Copenhagen", "Kobenhaagan" },
-            { "timezone.excity.Europe/Luxembourg", "Luksembaag" },
+            { "timezone.excity.Europe/Luxembourg", "Luksemberg" },
             { "timezone.excity.Europe/San_Marino", "San Mariino" },
             { "timezone.excity.Europe/Simferopol", "Simferobol" },
             { "timezone.excity.Europe/Zaporozhye", "Saborosey" },
