@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -182,6 +178,14 @@ public class TimeZoneNames_vi extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Casey = new String[] {
+               "Gi\u1edd Casey",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Chile = new String[] {
                "Gi\u1edd Chu\u1ea9n Chile",
                "",
@@ -311,9 +315,9 @@ public class TimeZoneNames_vi extends TimeZoneNamesBundle {
                "",
             };
         final String[] Azores = new String[] {
-               "Gi\u1edd Chu\u1ea9n Azores",
+               "Gi\u1edd chu\u1ea9n Azores",
                "",
-               "Gi\u1edd M\u00f9a H\u00e8 Azores",
+               "Gi\u1edd m\u00f9a h\u00e8 Azores",
                "",
                "Gi\u1edd Azores",
                "",
@@ -766,14 +770,6 @@ public class TimeZoneNames_vi extends TimeZoneNamesBundle {
                "Gi\u1edd Lord Howe",
                "",
             };
-        final String[] Macquarie = new String[] {
-               "Gi\u1edd \u0111\u1ea3o Macquarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Marquesas = new String[] {
                "Gi\u1edd Marquesas",
                "",
@@ -1309,7 +1305,7 @@ public class TimeZoneNames_vi extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1468,7 +1464,7 @@ public class TimeZoneNames_vi extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Pacific },
+            { "America/Dawson", America_Mountain },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1594,7 +1590,7 @@ public class TimeZoneNames_vi extends TimeZoneNamesBundle {
             { "America/St_Kitts", Atlantic },
             { "America/St_Lucia", Atlantic },
             { "America/Winnipeg", America_Central },
-            { "Antarctica/Casey", Australia_Western },
+            { "Antarctica/Casey", Casey },
             { "Antarctica/Davis", Davis },
             { "Antarctica/Syowa", Syowa },
             { "Antarctica/Troll", GMT },
@@ -1675,7 +1671,7 @@ public class TimeZoneNames_vi extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Pacific },
+            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1715,7 +1711,7 @@ public class TimeZoneNames_vi extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "Antarctica/Macquarie", Macquarie },
+            { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
@@ -1780,7 +1776,7 @@ public class TimeZoneNames_vi extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Taipei", "\u0110\u00e0i B\u1eafc" },
             { "timezone.excity.Asia/Tehran", "Tehran" },
             { "timezone.excity.Asia/Urumqi", "Urumqi" },
-            { "timezone.excity.Etc/Unknown", "Th\u00e0nh ph\u1ed1 Kh\u00f4ng x\u00e1c \u0111\u1ecbnh" },
+            { "timezone.excity.Etc/Unknown", "Th\u00e0nh ph\u1ed1 kh\u00f4ng x\u00e1c \u0111\u1ecbnh" },
             { "timezone.excity.Europe/Kiev", "Kiev" },
             { "timezone.excity.Europe/Oslo", "Oslo" },
             { "timezone.excity.Europe/Riga", "Riga" },
